.. raw:: html

    <p align="center">
        <a href="https://glia.rtfd.io"><img align="center" width="117" src="https://i.imgur.com/5jxLy6X.png"/></a>
    </p>
    <h4 align="center">G L I A</h4>
    <p align="center">
        Offical Desktop Client for Glial Engines
        <br>
        <br>
        <a href="https://travis-ci.com/GliaHQ/Glia">
            <img src="https://travis-ci.com/GliaHQ/Glia.svg?branch=master"/>
        </a>
        <a href="https://ci.appveyor.com/project/daegontaven/glia/branch/master">
            <img src="https://ci.appveyor.com/api/projects/status/yo5fg44wpkf9rk4w?svg=true"/>
        </a>
        <a href="https://codeclimate.com/github/GliaHQ/Glia/maintainability">
            <img src="https://api.codeclimate.com/v1/badges/3a7bc7e815dbac6d01d3/maintainability">
        </a>
        <a href="https://codecov.io/gh/GliaHQ/Glia">
            <img src="https://codecov.io/gh/GliaHQ/Glia/branch/master/graph/badge.svg">
        </a>
        <a href="https://glia-docs.readthedocs.io/en/latest/?badge=latest">
            <img src="https://readthedocs.org/projects/glia-docs/badge/?version=latest" alt="Documentation Status"/>
        </a>
    </p>
